package com.goer.project.model.modelVersionChanges.mapper;

import java.util.List;
import com.goer.project.model.modelVersionChanges.domain.ModelVersionChanges;
import org.springframework.stereotype.Repository;

/**
 * 模型对象版本修改内容Mapper接口
 * 
 * @author goer
 * @date 2022-01-17
 */
@Repository
public interface ModelVersionChangesMapper 
{
    /**
     * 查询模型对象版本修改内容
     * 
     * @param id 模型对象版本修改内容主键
     * @return 模型对象版本修改内容
     */
    public ModelVersionChanges selectModelVersionChangesById(Long id);

    /**
     * 查询模型对象版本修改内容列表
     * 
     * @param modelVersionChanges 模型对象版本修改内容
     * @return 模型对象版本修改内容集合
     */
    public List<ModelVersionChanges> selectModelVersionChangesList(ModelVersionChanges modelVersionChanges);

    /**
     * 新增模型对象版本修改内容
     * 
     * @param modelVersionChanges 模型对象版本修改内容
     * @return 结果
     */
    public int insertModelVersionChanges(ModelVersionChanges modelVersionChanges);

    /**
     * 修改模型对象版本修改内容
     * 
     * @param modelVersionChanges 模型对象版本修改内容
     * @return 结果
     */
    public int updateModelVersionChanges(ModelVersionChanges modelVersionChanges);

    /**
     * 删除模型对象版本修改内容
     * 
     * @param id 模型对象版本修改内容主键
     * @return 结果
     */
    public int deleteModelVersionChangesById(Long id);

    /**
     * 删除
     *
     * @param projectId 模型对象id
     * @return 结果
     */
    public int deleteModelVersionChangesByProjectId(Long projectId);

    /**
     * 批量删除模型对象版本修改内容
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteModelVersionChangesByIds(String[] ids);
}
